==> libgtk-java-2.5.2.tar.bz2: libgtk-java-2.5.2/src/java/org/gnu/gtk/ActionEntry.java <==
/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import java.util.ArrayList;
import java.util.List;

import org.gnu.glib.Boxed;
import org.gnu.gtk.event.ActionEntryListener;

/**
 */
public class ActionEntry extends Boxed {

	/**
	 * ActionEntryListener objects that are interested in events for this
	 * entry.
	 */
	private List listeners = new ArrayList();

	public ActionEntry(String name, String stockId, String label) {
		this(name, stockId, label, null, null, null);
	}

	public ActionEntry(
		String name,
		String stockId,
		String label,
		String accel,
		String tooltip,
		ActionEntryListener listener) {

		// create the native object
		handle = allocate();
		// set the values
		setName(handle, name);
		setStockId(handle, stockId);
		setLabel(handle, label);
		setAccelerator(handle, accel);
		setToolTip(handle, tooltip);
		if (null != listener) {
			listeners.add(listener);
		}
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#finalize()
	 */
	protected void finalize() throws Throwable {
		super.finalize();
		free(handle);
	}

	public void addListener(ActionEntryListener listener) {
		listeners.add(listener);
	}

	public void removeListener(ActionEntryListener listener) {
		listeners.remove(listener);
	}

	private void handleCallback(int action) {
		for (int i = 0; i < listeners.size(); i++) {
			ActionEntryListener l = (ActionEntryListener)listeners.get(i);
			l.actionEvent(new Action(action));
		}
	}

	/***************************************************************************
	 * BEGINNING OF JNI CODE
	 **************************************************************************/
	native static final protected int allocate();
	native static final protected void free(int entry);
	native static final protected void setName(int entry, String name);
	native static final protected void setStockId(int entry, String stockId);
	native static final protected void setLabel(int entry, String label);
	native static final protected void setAccelerator(int entry, String accel);
	native static final protected void setToolTip(int entry, String tooltip);
	/***************************************************************************
	 * END OF JNI CODE
	 **************************************************************************/
}

==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gtk/ActionEntry.java <==
/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import java.util.ArrayList;
import java.util.List;

import org.gnu.glib.MemStruct;
import org.gnu.gtk.event.ActionEntryListener;
import org.gnu.javagnome.Handle;

/**
 */
public class ActionEntry extends MemStruct {

	/**
	 * ActionEntryListener objects that are interested in events for this
	 * entry.
	 */
	private List listeners = new ArrayList();

	public ActionEntry(String name, String stockId, String label) {
		this(name, stockId, label, null, null, null);
	}

	public ActionEntry(
		String name,
		String stockId,
		String label,
		String accel,
		String tooltip,
		ActionEntryListener listener) {

		// create the native object
		super(allocate());
		// set the values
		setName(getHandle(), name);
		setStockId(getHandle(), stockId);
		setLabel(getHandle(), label);
		setAccelerator(getHandle(), accel);
		setToolTip(getHandle(), tooltip);
		if (null != listener) {
			listeners.add(listener);
		}
	}

	public void addListener(ActionEntryListener listener) {
		listeners.add(listener);
	}

	public void removeListener(ActionEntryListener listener) {
		listeners.remove(listener);
	}

	private void handleCallback(Handle action) {
		for (int i = 0; i < listeners.size(); i++) {
			ActionEntryListener l = (ActionEntryListener)listeners.get(i);
			l.actionEvent(Action.getAction(action));
		}
	}

	/***************************************************************************
	 * BEGINNING OF JNI CODE
	 **************************************************************************/
	native static final protected Handle allocate();
	native static final protected void setName(Handle entry, String name);
	native static final protected void setStockId(Handle entry, String stockId);
	native static final protected void setLabel(Handle entry, String label);
	native static final protected void setAccelerator(Handle entry, String accel);
	native static final protected void setToolTip(Handle entry, String tooltip);
	/***************************************************************************
	 * END OF JNI CODE
	 **************************************************************************/
}
